==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/General/statusicon/translations/statusicon_plugin_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk_SK">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Status Icon Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Balloon message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Delay, ms:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Tooltip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="91"/>
        <source>Try to split file name when no tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="98"/>
        <source>Show progress bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Transparency:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="165"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Cover size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="214"/>
        <source>32</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="225"/>
        <source>Edit template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <source>Use standard icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="80"/>
        <source>Tooltip Template</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatusIcon</name>
    <message>
        <location filename="../statusicon.cpp" line="70"/>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="71"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="72"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="74"/>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="75"/>
        <source>Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="77"/>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="119"/>
        <source>Stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="144"/>
        <source>Now Playing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatusIconFactory</name>
    <message>
        <location filename="../statusiconfactory.cpp" line="30"/>
        <source>Status Icon Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="50"/>
        <source>About Status Icon Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="51"/>
        <source>Qmmp Status Icon Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="52"/>
        <source>Written by:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="53"/>
        <source>Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="54"/>
        <source>Artur Guzik &lt;a.guzik88@gmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/General/statusicon/translations/statusicon_plugin_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Status Icon Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Balloon message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Delay, ms:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Tooltip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="91"/>
        <source>Try to split file name when no tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="98"/>
        <source>Show progress bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Transparency:</source>
        <translation>Priehľadnosť:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="165"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Cover size:</source>
        <translation>Veľkosť obalu:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="214"/>
        <source>32</source>
        <translation type="unfinished">32</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="225"/>
        <source>Edit template</source>
        <translation>Upraviť šablónu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <source>Use standard icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="80"/>
        <source>Tooltip Template</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatusIcon</name>
    <message>
        <location filename="../statusicon.cpp" line="71"/>
        <source>Play</source>
        <translation>Hrať</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="72"/>
        <source>Pause</source>
        <translation>Pozastaviť</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="73"/>
        <source>Stop</source>
        <translation>Zastaviť</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="75"/>
        <source>Next</source>
        <translation>Nasledujúca</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="76"/>
        <source>Previous</source>
        <translation>Predchádzajúca</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="78"/>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="120"/>
        <source>Stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="145"/>
        <source>Now Playing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatusIconFactory</name>
    <message>
        <location filename="../statusiconfactory.cpp" line="29"/>
        <source>Status Icon Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="49"/>
        <source>About Status Icon Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="50"/>
        <source>Qmmp Status Icon Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="51"/>
        <source>Written by:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="52"/>
        <source>Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="53"/>
        <source>Artur Guzik &lt;a.guzik88@gmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
